← Back to team overview

launchpad-reviewers team mailing list archive

[Merge] lp:~deryck/launchpad/rockstar-js-refresh into lp:launchpad/devel

 

Deryck Hodge has proposed merging lp:~deryck/launchpad/rockstar-js-refresh into lp:launchpad/devel with lp:~rockstar/launchpad/javascript-refresh as a prerequisite.

Requested reviews:
  Launchpad code reviewers (launchpad-reviewers)
Related bugs:
  #672576 LP needs updating to lazr-js tip to finish subscriptions work
  https://bugs.launchpad.net/bugs/672576


This is my attempt to get rockstar's javascript-refresh branch ready to land.  It basically amounts to a bunch of sed's for yui to yui3 and a couple test fixes that were fragile.  Since rockstar's branch (see pre-req branch) has already been approved, I'm going to land this unreviewed.

I've done a lot of manual testing, besides several ec2 runs, and I will create a bug to track QA on this change, since we will need to manually check out qastaging pretty heavily before approving this to deploy.
-- 
https://code.launchpad.net/~deryck/launchpad/rockstar-js-refresh/+merge/40329
Your team Launchpad code reviewers is requested to review the proposed merge of lp:~deryck/launchpad/rockstar-js-refresh into lp:launchpad/devel.
=== modified file 'lib/canonical/launchpad/doc/lazr-js-widgets.txt'
--- lib/canonical/launchpad/doc/lazr-js-widgets.txt	2010-10-18 22:24:59 +0000
+++ lib/canonical/launchpad/doc/lazr-js-widgets.txt	2010-11-08 14:45:43 +0000
@@ -25,7 +25,7 @@
 content.
 
     >>> print widget()
-    <h1 id="..."><span class="yui-editable_text-text">My bug is &gt;
+    <h1 id="..."><span class="yui3-editable_text-text">My bug is &gt;
         important</span>
     </h1>
 
@@ -35,10 +35,10 @@
 
     >>> login('no-priv@xxxxxxxxxxxxx')
     >>> print widget()
-    <h1 id="..."><span class="yui-editable_text-text">My bug is &gt;
+    <h1 id="..."><span class="yui3-editable_text-text">My bug is &gt;
         important</span>
         <a href="http://bugs.launchpad.dev/.../+edit";
-           class="yui-editable_text-trigger sprite edit"
+           class="yui3-editable_text-trigger sprite edit"
         ></a>
     </h1>
     <script>
@@ -53,7 +53,7 @@
     ...     id="bug-title", title="Edit this summary")
     >>> print widget()
     <h1 id="bug-title">...
-        ...class="yui-editable_text-trigger sprite edit"...
+        ...class="yui3-editable_text-trigger sprite edit"...
 
 The initial_value_override parameter is passed as a JSON-serialized value.
 
@@ -107,7 +107,7 @@
     False
     >>> print widget()
     <span id="inline-picker-activator-id-...">...
-    <div class="yui-activator-message-box yui-activator-hidden" />
+    <div class="yui3-activator-message-box yui3-activator-hidden" />
     </span>
 
 The foo.bar user can see the activator's edit button.
@@ -118,7 +118,7 @@
     True
     >>> print widget()
     <span id="inline-picker-activator-id-...">
-    ...<div class="yui-activator-message-box yui-activator-hidden" />
+    ...<div class="yui3-activator-message-box yui3-activator-hidden" />
     </span>
     ...Y.lp.app.picker.addPickerPatcher(...
 

=== modified file 'lib/canonical/launchpad/windmill/testing/widgets.py'
--- lib/canonical/widgets/lazrjs.py	2010-09-24 18:10:31 +0000
+++ lib/canonical/widgets/lazrjs.py	2010-11-08 14:45:43 +0000
@@ -47,7 +47,7 @@
     #   value: the current field value
     WIDGET_TEMPLATE = dedent(u"""\
         <%(tag)s id="%(id)s"><span
-            class="yui-editable_text-text">%(value)s</span>
+            class="yui3-editable_text-text">%(value)s</span>
             %(trigger)s
         </%(tag)s>
         %(activation_script)s
@@ -55,7 +55,7 @@
 
     # Template for the trigger button.
     TRIGGER_TEMPLATE = dedent(u"""\
-        <a href="%(edit_url)s" class="yui-editable_text-trigger sprite edit"
+        <a href="%(edit_url)s" class="yui3-editable_text-trigger sprite edit"
         ></a>
         """)
 
@@ -185,7 +185,7 @@
             %(edit_controls)s
             <h2>%(title)s</h2>
           </div>
-          <div class="yui-editable_text-text">%(value)s</div>
+          <div class="yui3-editable_text-text">%(value)s</div>
         </div>
         %(activation_script)s
         """)

=== modified file 'lib/canonical/widgets/templates/inline-picker.pt'
--- lib/canonical/widgets/templates/inline-picker.pt	2010-07-15 10:59:22 +0000
+++ lib/canonical/widgets/templates/inline-picker.pt	2010-11-08 14:45:43 +0000
@@ -1,11 +1,11 @@
 <span tal:attributes="id view/id">
-    <span class="yui-activator-data-box">
+    <span class="yui3-activator-data-box">
     <tal:attribute replace="structure view/default_html"/>
     </span>
-    <button class="lazr-btn yui-activator-act yui-activator-hidden">
+    <button class="lazr-btn yui3-activator-act yui3-activator-hidden">
       Edit
     </button>
-    <div class="yui-activator-message-box yui-activator-hidden"/>
+    <div class="yui3-activator-message-box yui3-activator-hidden"/>
 </span>
 <script tal:condition="view/can_write"
         tal:content="structure string:

=== modified file 'lib/lp/app/browser/tests/base-layout.txt'
--- lib/lp/app/browser/tests/base-layout.txt	2010-10-26 01:26:00 +0000
+++ lib/lp/app/browser/tests/base-layout.txt	2010-11-08 14:45:43 +0000
@@ -219,7 +219,7 @@
     >>> view = LocationlessView(team, request)
     >>> body = find_tag_by_id(view.render(), 'document')
     >>> print body['class']
-    tab-overview locationless private yui-skin-sam
+    tab-overview locationless private yui3-skin-sam
 
 When the context is public, the 'public' class is in the class attribute.
 
@@ -228,7 +228,7 @@
     >>> view = LocationlessView(team, request)
     >>> body = find_tag_by_id(view.render(), 'document')
     >>> print body['class']
-    tab-overview locationless public yui-skin-sam
+    tab-overview locationless public yui3-skin-sam
 
 
 Notifications

=== modified file 'lib/lp/app/browser/tests/test_base_layout.py'
--- lib/lp/app/browser/tests/test_base_layout.py	2010-09-29 03:26:01 +0000
+++ lib/lp/app/browser/tests/test_base_layout.py	2010-11-08 14:45:43 +0000
@@ -106,7 +106,7 @@
         self.verify_base_layout_head_parts(view, content)
         document = find_tag_by_id(content, 'document')
         self.verify_base_layout_body_parts(document)
-        classes = 'tab-overview main_side public yui-skin-sam'.split()
+        classes = 'tab-overview main_side public yui3-skin-sam'.split()
         self.assertEqual(classes, document['class'].split())
         self.verify_watermark(document)
         self.assertEqual(
@@ -121,7 +121,7 @@
         self.verify_base_layout_head_parts(view, content)
         document = find_tag_by_id(content, 'document')
         self.verify_base_layout_body_parts(document)
-        classes = 'tab-overview main_only public yui-skin-sam'.split()
+        classes = 'tab-overview main_only public yui3-skin-sam'.split()
         self.assertEqual(classes, document['class'].split())
         self.verify_watermark(document)
         self.assertEqual(
@@ -138,7 +138,7 @@
         document = find_tag_by_id(content, 'document')
         self.verify_base_layout_body_parts(document)
         self.verify_watermark(document)
-        classes = 'tab-overview searchless public yui-skin-sam'.split()
+        classes = 'tab-overview searchless public yui3-skin-sam'.split()
         self.assertEqual(classes, document['class'].split())
         self.assertEqual(
             'registering', document.find(True, id='registration')['class'])
@@ -153,7 +153,7 @@
         self.verify_base_layout_head_parts(view, content)
         document = find_tag_by_id(content, 'document')
         self.verify_base_layout_body_parts(document)
-        classes = 'tab-overview locationless public yui-skin-sam'.split()
+        classes = 'tab-overview locationless public yui3-skin-sam'.split()
         self.assertEqual(classes, document['class'].split())
         self.assertEqual(None, document.find(True, id='registration'))
         self.assertEqual(None, document.find(True, id='watermark'))

=== added file 'lib/lp/app/configure.zcml'
--- lib/lp/app/configure.zcml	1970-01-01 00:00:00 +0000
+++ lib/lp/app/configure.zcml	2010-09-29 12:39:28 +0000
@@ -0,0 +1,14 @@
+<!-- Copyright 2009 Canonical Ltd.  This software is licensed under the
+     GNU Affero General Public License version 3 (see the file LICENSE).
+-->
+
+<configure
+    xmlns="http://namespaces.zope.org/zope";
+    xmlns:browser="http://namespaces.zope.org/browser";
+    xmlns:i18n="http://namespaces.zope.org/i18n";
+    xmlns:xmlrpc="http://namespaces.zope.org/xmlrpc";
+    xmlns:lp="http://namespaces.canonical.com/lp";
+    i18n_domain="launchpad">
+    <include
+        package=".browser"/>
+</configure>

=== modified file 'lib/lp/app/javascript/picker.js'
--- lib/lp/app/javascript/picker.js	2010-07-15 10:59:22 +0000
+++ lib/lp/app/javascript/picker.js	2010-11-08 14:45:43 +0000
@@ -56,7 +56,7 @@
     };
 
     var show_hide_buttons = function () {
-        var link = content_box.one('.yui-activator-data-box a');
+        var link = content_box.one('.yui3-activator-data-box a');
         if (remove_button) {
             if (link === null || !show_remove_button) {
                 remove_button.addClass('yui-picker-hidden');
@@ -223,8 +223,8 @@
 
     var new_config = Y.merge(config, {
         align: {
-            points: [Y.WidgetPositionExt.CC,
-                     Y.WidgetPositionExt.CC]
+            points: [Y.WidgetPositionAlign.CC,
+                     Y.WidgetPositionAlign.CC]
         },
         progressbar: true,
         progress: 100,

=== modified file 'lib/lp/app/javascript/tests/test_lp_collapsibles.html'
--- lib/lp/app/javascript/tests/test_lp_collapsibles.html	2010-07-26 13:42:32 +0000
+++ lib/lp/app/javascript/tests/test_lp_collapsibles.html	2010-11-08 14:45:43 +0000
@@ -17,7 +17,7 @@
   <!-- The test suite -->
   <script type="text/javascript" src="test_lp_collapsibles.js"></script>
 </head>
-<body class="yui-skin-sam">
+<body class="yui3-skin-sam">
   <div id="container-of-stuff">
   </div>
 </body>

=== modified file 'lib/lp/app/templates/base-layout-macros.pt'
--- lib/lp/app/templates/base-layout-macros.pt	2010-11-08 14:45:40 +0000
+++ lib/lp/app/templates/base-layout-macros.pt	2010-11-08 14:45:43 +0000
@@ -656,7 +656,7 @@
       tal:content="string:var cookie_scope = '${request/lp:cookie_scope}';"></script>
   <script type="text/javascript">
     // Define a global YUI sandbox that should be used by everyone.
-    var LPS = YUI();
+    var LPS = YUI({fetchCSS: false});
   </script>
 </metal:load-javascript>
 

=== modified file 'lib/lp/app/templates/base-layout.pt'
--- lib/lp/app/templates/base-layout.pt	2010-10-25 17:31:27 +0000
+++ lib/lp/app/templates/base-layout.pt	2010-11-08 14:45:43 +0000
@@ -69,7 +69,7 @@
     tal:attributes="class string:tab-${view/menu:selectedfacetname}
       ${view/macro:pagetype}
       ${view/context/fmt:public-private-css}
-      yui-skin-sam">
+      yui3-skin-sam">
         <script type="text/javascript"
           tal:condition="python: is_lpnet">
           var _gaq = _gaq || [];

=== modified file 'lib/lp/bugs/javascript/bugtask_index.js'
--- lib/lp/bugs/javascript/bugtask_index.js	2010-08-02 17:49:45 +0000
+++ lib/lp/bugs/javascript/bugtask_index.js	2010-11-08 14:45:43 +0000
@@ -1338,8 +1338,8 @@
                     bugtarget_content.replaceChild(
                         Y.DOM.create(
                             '<a href="+editstatus" ' +
-                            '   class="sprite edit yui-activator-act" />'),
-                        bugtarget_content.one('.yui-activator-act'));
+                            '   class="sprite edit yui3-activator-act" />'),
+                        bugtarget_content.one('.yui3-activator-act'));
                 } else {
                     var bugtarget_picker = Y.lp.app.picker.addPickerPatcher(
                         'Product',

=== modified file 'lib/lp/bugs/javascript/official_bug_tags.js'
--- lib/lp/bugs/javascript/official_bug_tags.js	2010-11-03 15:49:43 +0000
+++ lib/lp/bugs/javascript/official_bug_tags.js	2010-11-08 14:45:43 +0000
@@ -355,7 +355,7 @@
                      '<img src="/@@/error" />&nbsp;Invalid Tag</span>',
       bodyContent: Y.Lang.substitute(ERROR_MSG, {new_tag: new_tag}),
       align: {
-        points: [Y.WidgetPositionExt.CC, Y.WidgetPositionExt.CC]
+        points: [Y.WidgetPositionAlign.CC, Y.WidgetPositionAlign.CC]
       },
       progressbar: false,
       progress: 0

=== modified file 'lib/lp/bugs/javascript/tests/test_bug_subscription_widget.html'
--- lib/lp/bugs/javascript/tests/test_bug_subscription_widget.html	2010-08-20 13:22:03 +0000
+++ lib/lp/bugs/javascript/tests/test_bug_subscription_widget.html	2010-11-08 14:45:43 +0000
@@ -35,7 +35,7 @@
     .unseen { display: none; }
   </style>
 </head>
-<body class="yui-skin-sam">
+<body class="yui3-skin-sam">
   <div id="log"></div>
 </body>
 </html>

=== modified file 'lib/lp/bugs/javascript/tests/test_me_too.html'
--- lib/lp/bugs/javascript/tests/test_me_too.html	2010-07-11 00:32:53 +0000
+++ lib/lp/bugs/javascript/tests/test_me_too.html	2010-11-08 14:45:43 +0000
@@ -35,7 +35,7 @@
     .unseen { display: none; }
   </style>
 </head>
-<body class="yui-skin-sam">
+<body class="yui3-skin-sam">
   <div id="log"></div>
 </body>
 </html>

=== modified file 'lib/lp/bugs/javascript/tests/test_me_too.js'
--- lib/lp/bugs/javascript/tests/test_me_too.js	2010-10-24 21:00:11 +0000
+++ lib/lp/bugs/javascript/tests/test_me_too.js	2010-11-08 14:45:43 +0000
@@ -20,19 +20,6 @@
     Y.Event.simulate(rawnode, evtype, options);
 }
 
-/* Helper function to clean up a dynamically added widget instance. */
-function cleanup_widget(widget) {
-    // Nuke the boundingBox, but only if we've touched the DOM.
-    if (widget.get('rendered')) {
-        var bb = widget.get('boundingBox');
-        if (bb.get('parentNode')) {
-            bb.get('parentNode').removeChild(bb);
-        }
-    }
-    // Kill the widget itself.
-    widget.destroy();
-}
-
 var suite = new Y.Test.Suite("Bugtask Me-Too Choice Edit Tests");
 
 suite.add(new Y.Test.Case({
@@ -79,9 +66,6 @@
     },
 
     tearDown: function() {
-        if (this.choice_edit._choice_list) {
-            cleanup_widget(this.choice_edit._choice_list);
-        }
         var status = Y.one("document").one("#affectsmetoo");
         if (status) {
             status.get("parentNode").removeChild(status);

=== modified file 'lib/lp/bugs/javascript/tests/test_subscriber.html'
--- lib/lp/bugs/javascript/tests/test_subscriber.html	2010-07-11 00:32:53 +0000
+++ lib/lp/bugs/javascript/tests/test_subscriber.html	2010-11-08 14:45:43 +0000
@@ -29,7 +29,7 @@
       div#sample {margin:15px; width:200px; border:1px solid #999; padding:10px;}
     </style>
   </head>
-  <body class="yui-skin-sam">
+  <body class="yui3-skin-sam">
     <!-- Example markup required by test suite -->
   <div id="sample">
     <div class="section">

=== modified file 'lib/lp/bugs/templates/bugtask-tasks-and-nominations-table-row.pt'
--- lib/lp/bugs/templates/bugtask-tasks-and-nominations-table-row.pt	2010-06-15 13:51:55 +0000
+++ lib/lp/bugs/templates/bugtask-tasks-and-nominations-table-row.pt	2010-11-08 14:45:43 +0000
@@ -38,7 +38,7 @@
     </td>
     <td tal:condition="not:indent_task">
       <span tal:attributes="id string:bugtarget-picker-${row_id}">
-        <span class="yui-activator-data-box">
+        <span class="yui3-activator-data-box">
           <span title="This project&rsquo;s license has not been specified.">
             <a tal:attributes="href context/target/fmt:url;
                                title view/target_link_title;
@@ -46,10 +46,10 @@
                tal:content="context/bugtargetdisplayname" />
           </span>
         </span>
-        <button class="lazr-btn yui-activator-act yui-activator-hidden">
+        <button class="lazr-btn yui3-activator-act yui3-activator-hidden">
           Edit
         </button>
-        <div class="yui-activator-message-box yui-activator-hidden" />
+        <div class="yui3-activator-message-box yui3-activator-hidden" />
       </span>
     </td>
 
@@ -131,7 +131,7 @@
 
       <tal:has_no_watch condition="not: context/bugwatch">
         <span tal:attributes="id string:assignee-picker-${row_id}">
-          <span class="yui-activator-data-box">
+          <span class="yui3-activator-data-box">
             <a tal:condition="context/assignee"
                tal:attributes="href context/assignee/fmt:url;
                                class context/assignee/image:sprite_css"
@@ -140,10 +140,10 @@
               Unassigned
             </tal:unassigned>
           </span>
-          <button class="lazr-btn yui-activator-act yui-activator-hidden">
+          <button class="lazr-btn yui3-activator-act yui3-activator-hidden">
             Edit
           </button>
-          <div class="yui-activator-message-box yui-activator-hidden" />
+          <div class="yui3-activator-message-box yui3-activator-hidden" />
         </span>
       </tal:has_no_watch>
     </td>

=== renamed file 'lib/lp/bugs/windmill/tests/test_bug_also_affects_new_upstream.py.disabled' => 'lib/lp/bugs/windmill/tests/test_bug_also_affects_new_upstream.py'
=== renamed file 'lib/lp/bugs/windmill/tests/test_bug_inline_subscriber.py.disabled' => 'lib/lp/bugs/windmill/tests/test_bug_inline_subscriber.py'
--- lib/lp/bugs/windmill/tests/test_bug_inline_subscriber.py.disabled	2010-11-08 14:45:40 +0000
+++ lib/lp/bugs/windmill/tests/test_bug_inline_subscriber.py	2010-11-08 14:45:43 +0000
@@ -227,7 +227,7 @@
         # Now back to bug 5. Confirm there are 2 subscriptions.
         client.open(url=BUG_URL % 5)
         client.waits.forPageLoad(timeout=PAGE_LOAD)
-        client.asserts.assertNode(
+        client.waits.forElement(
             id='direct-subscriber-12', timeout=FOR_ELEMENT)
         # The first click unsubscribes the direct subscription, leaving
         # the duplicate subscription.

=== renamed file 'lib/lp/bugs/windmill/tests/test_bug_me_too.py.disabled' => 'lib/lp/bugs/windmill/tests/test_bug_me_too.py'
=== renamed file 'lib/lp/bugs/windmill/tests/test_bug_tags_entry.py.disabled' => 'lib/lp/bugs/windmill/tests/test_bug_tags_entry.py'
=== modified file 'lib/lp/code/javascript/branchmergeproposal.diff.js'
--- lib/lp/code/javascript/branchmergeproposal.diff.js	2010-11-08 14:45:40 +0000
+++ lib/lp/code/javascript/branchmergeproposal.diff.js	2010-11-08 14:45:43 +0000
@@ -73,8 +73,8 @@
                 var diff_overlay = new DiffOverlay({
                         bodyContent: Y.Node.create(formatted_diff),
                         align: {
-                            points: [Y.WidgetPositionExt.CC,
-                                     Y.WidgetPositionExt.CC]
+                            points: [Y.WidgetPositionAlign.CC,
+                                     Y.WidgetPositionAlign.CC]
                         },
                         progressbar: false
                     });

=== modified file 'lib/lp/code/javascript/tests/test_productseries-setbranch.html'
--- lib/lp/code/javascript/tests/test_productseries-setbranch.html	2010-04-29 15:21:05 +0000
+++ lib/lp/code/javascript/tests/test_productseries-setbranch.html	2010-11-08 14:45:43 +0000
@@ -25,7 +25,7 @@
   <script type="text/javascript" src="test_productseries_setbranch.js"></script>
   </head>
 
-<body class="yui-skin-sam">
+<body class="yui3-skin-sam">
   <div id="productseries-setbranch">
   <form action="." name="launchpadform" method="post"
         enctype="multipart/form-data"

=== modified file 'lib/lp/registry/javascript/tests/test_milestone_table.html'
--- lib/lp/registry/javascript/tests/test_milestone_table.html	2010-04-28 18:43:25 +0000
+++ lib/lp/registry/javascript/tests/test_milestone_table.html	2010-11-08 14:45:43 +0000
@@ -18,7 +18,7 @@
   <script type="text/javascript" src="test_milestone_table.js"></script>
 
 </head>
-<body class="yui-skin-sam">
+<body class="yui3-skin-sam">
   <table id="series-trunk" class="listing">
     <thead>
       <tr>

=== modified file 'lib/lp/registry/javascript/tests/timeline-iframe.html'
--- lib/lp/registry/javascript/tests/timeline-iframe.html	2010-04-28 18:43:25 +0000
+++ lib/lp/registry/javascript/tests/timeline-iframe.html	2010-11-08 14:45:43 +0000
@@ -41,7 +41,7 @@
   }
   </style>
 </head>
-<body class="yui-skin-sam">
+<body class="yui3-skin-sam">
   <div id="timeline_example">
   </div>
   <div id="log"></div>

=== modified file 'lib/lp/soyuz/javascript/tests/test_archivesubscribers_index.html'
--- lib/lp/soyuz/javascript/tests/test_archivesubscribers_index.html	2010-08-10 09:32:38 +0000
+++ lib/lp/soyuz/javascript/tests/test_archivesubscribers_index.html	2010-11-08 14:45:43 +0000
@@ -16,7 +16,7 @@
   <!-- The test suite -->
   <script type="text/javascript" src="archivesubscribers_index.js"></script>
 </head>
-<body class="yui-skin-sam">
+<body class="yui3-skin-sam">
   <h1>Testing the ArchiveSubscribersIndex javascript</h1>
 
   <h2>Errors</h2>

=== modified file 'lib/lp/soyuz/javascript/tests/test_lp_dynamic_dom_updater.html'
--- lib/lp/soyuz/javascript/tests/test_lp_dynamic_dom_updater.html	2010-08-10 09:32:38 +0000
+++ lib/lp/soyuz/javascript/tests/test_lp_dynamic_dom_updater.html	2010-11-08 14:45:43 +0000
@@ -16,7 +16,7 @@
   <!-- The test suite -->
   <script type="text/javascript" src="lp_dynamic_dom_updater.js"></script>
 </head>
-<body class="yui-skin-sam">
+<body class="yui3-skin-sam">
   <div id="lp_dynamic_dom_updater_example">
   </div>
   <div id="log"></div>

=== modified file 'lib/lp/testing/__init__.py'
--- lib/lp/testing/__init__.py	2010-11-02 03:38:53 +0000
+++ lib/lp/testing/__init__.py	2010-11-08 14:45:43 +0000
@@ -744,10 +744,10 @@
         # Maybe testing.pages should move to lp to avoid circular imports.
         from canonical.launchpad.testing.pages import find_tags_by_class
         entries = find_tags_by_class(
-            response['result'], 'yui-console-entry-TestRunner')
+            response['result'], 'yui3-console-entry-TestRunner')
         for entry in entries:
             category = entry.find(
-                attrs={'class': 'yui-console-entry-cat'})
+                attrs={'class': 'yui3-console-entry-cat'})
             if category is None:
                 continue
             result = category.string

=== renamed file 'lib/lp/translations/windmill/tests/test_import_queue_error_output.py.disabled' => 'lib/lp/translations/windmill/tests/test_import_queue_error_output.py'
--- lib/canonical/launchpad/windmill/testing/widgets.py	2010-11-07 18:37:37 +0000
+++ lib/canonical/launchpad/windmill/testing/widgets.py	2010-11-08 14:45:43 +0000
@@ -33,7 +33,7 @@
         """Constructor.
 
         :param client: A WindmillTestClient instance for interacting with pages.
         :param widget_name: The class name of the YUI widget, like 'yui-picker'.
         """
         self.client = client
         self.widget_name = widget_name
@@ -76,22 +76,22 @@
 
 
 class SearchPickerWidget(OnPageWidget):
     """A proxy for the yui-picker widget from lazr-js."""
 
     def __init__(self, client):
         """Constructor.
 
         :param client: A WindmillTestClient instance.
         """
-        super(SearchPickerWidget, self).__init__(client, 'yui-picker')
+        super(SearchPickerWidget, self).__init__(client, 'yui3-picker')
         self.search_input_xpath = (
-            self.xpath + "//input[@class='yui-picker-search']")
+            self.xpath + "//input[@class='yui3-picker-search']")
         self.search_button_xpath = (
-            self.xpath + "//div[@class='yui-picker-search-box']/button")
+            self.xpath + "//div[@class='yui3-picker-search-box']/button")
 
     def _get_result_xpath_by_number(self, item_number):
         """Return the XPath for the given search result number."""
-        item_xpath = "//ul[@class='yui-picker-results']/li[%d]/span" % item_number
+        item_xpath = "//ul[@class='yui3-picker-results']/li[%d]/span" % item_number
         return self.xpath + item_xpath
 
     def do_search(self, text):
@@ -234,7 +234,7 @@
         # Click on edit button.
         button_xpath = (
             u"//span[@id='%s']"
-             "/button[not(contains(@class, 'yui-activator-hidden'))]"
+             "/button[not(contains(@class, 'yui3-activator-hidden'))]"
              % self.activator_id)
         client.waits.forElement(
             xpath=button_xpath,
@@ -303,15 +303,15 @@
         # Click on edit button.
         button_xpath = (
             u"//span[@id='%s']"
-             "/button[not(contains(@class, 'yui-activator-hidden'))]"
+             "/button[not(contains(@class, 'yui3-activator-hidden'))]"
              % self.activator_id)
         client.waits.forElement(xpath=button_xpath, timeout=u'25000')
         client.click(xpath=button_xpath)
 
         # Click on remove button.
         remove_button_xpath = (
-            u"//div[contains(@class, 'yui-picker ') "
-             "and not(contains(@class, 'yui-picker-hidden'))]"
+            u"//div[contains(@class, 'yui3-picker ') "
+             "and not(contains(@class, 'yui3-picker-hidden'))]"
              "//*[contains(@class, '%s')]" % self.button_class)
         client.waits.forElement(xpath=remove_button_xpath, timeout=u'25000')
         client.click(xpath=remove_button_xpath)
@@ -319,7 +319,7 @@
 
         # Verify removal.
         client.asserts.assertText(
-            xpath=u"//span[@id='%s']/span[@class='yui-activator-data-box']"
+            xpath=u"//span[@id='%s']/span[@class='yui3-activator-data-box']"
                   % self.activator_id,
             validator=self.new_value)
 
@@ -329,11 +329,11 @@
 
         # Verify removal, again.
         client.waits.forElement(
-            xpath=u"//span[@id='%s']/span[@class='yui-activator-data-box']"
+            xpath=u"//span[@id='%s']/span[@class='yui3-activator-data-box']"
                   % self.activator_id,
             timeout=u'25000')
         client.asserts.assertText(
-            xpath=u"//span[@id='%s']/span[@class='yui-activator-data-box']"
+            xpath=u"//span[@id='%s']/span[@class='yui3-activator-data-box']"
                   % self.activator_id,
             validator=self.new_value)
 
@@ -33,7 +33,7 @@
 
         :param client: A WindmillTestClient instance for interacting with pages.
-        :param widget_name: The class name of the YUI widget, like 'yui-picker'.
+        :param widget_name: The class name of the YUI widget, like 'yui3-picker'.
         """
         self.client = client
@@ -76,22 +76,22 @@
 
 class SearchPickerWidget(OnPageWidget):
-    """A proxy for the yui-picker widget from lazr-js."""
+    """A proxy for the yui3-picker widget from lazr-js."""
 
     def __init__(self, client):

=== modified file 'lib/canonical/widgets/lazrjs.py'